#ifndef COMMON_H
#define COMMON_H

/**
  * This file should contain all the data structures and variables
  * that are shared between the lexical analyzer and the parser.
  * These include, but are not limited to, the symbol table, a shared integer for
  * communicating numbers and symbol table locations and the possible types for
  * tokens.
  */

#define SYMMAX 20		/** size of symbol table */

/** Different types of tokens that are recognized */
enum TokenType 
{
	SEMICOLON, COMMA, END, LBRACE, RBRACE, LBRACK, RBRACK,
	RPAREN, LPAREN, NUMBER, IDENT, WHILE, DO, ASSIGN, BAD,
	IF, THEN, ELSE,
	RELOP,
	PLUS, MINUS,
	TIMES, DIVIDE,
	ENDFILE
};

/** Symbol table structure */
extern struct SymbolTable
{
	char name[9];			/** identifier name */
	int  size;				/** zero for scalar; number of elements for vector */
	int  countRead;     	/** count the read references. */
	int  countWrite;   		/** count the write references */
} gSymTab[SYMMAX];			/** symbol table */

extern int gSharedValue;	/** Shared integer between lexical analyzer and parser */



#endif
